@@ -1,9 +1,4 @@
-"""
-xml_files.py
-This module is responsible for reading the Civ4 XML files and transforming them
-into python Enums.
-"""
-
+"""This module is responsible for parsing the XML files."""
 import re
 from dataclasses import dataclass, field
 from enum import Enum
@@ -17,6 +12,7 @@ from civ4save.utils import get_game_dir
 
 
 def get_n_parents(path: Path, num: int) -> Path:
+    """Return a shortened path with only `num` parents."""
     path = path.resolve()
     name = path.name
     parents = []
@@ -30,22 +26,27 @@ def get_n_parents(path: Path, num: int) -> Path:
 
 @dataclass
 class Civ4XmlFile:
+    """Helper class for transforming XML file to Python Enum."""
     path: Path
     _parsed: dict = field(default_factory=dict)
 
     def __post_init__(self):
+        """Validate actually xml file."""
         if not self.path.suffix == ".xml":
             raise ValueError(f"{get_n_parents(self.path, 4)} not a xml file")
 
     def __str__(self) -> str:
+        """Return shorted string representation of XML file path."""
         return str(get_n_parents(self.path, 4))
 
     @property
-    def name(self):
+    def name(self) -> str:
+        """The file name."""
         return self.path.name
 
     @property
-    def enum_name(self):
+    def enum_name(self) -> str:
+        """Name of the Enum corresponding to the XML file."""
         name = self.path.stem.replace("Infos", "")
         name = name.replace("CIV4", "")
         name = name.replace("Info", "")
@@ -53,12 +54,14 @@ class Civ4XmlFile:
         return name + "Type"
 
     @property
-    def negative_one(self):
+    def negative_one(self) -> str:
+        """Return the default NO_<SOMETHING> = -1 name for the Enum."""
         name = re.sub(r'(?<!^)(?=[A-Z])', '_', self.enum_name)
         return "NO_" + name.replace("_Type", "").upper()
 
     @property
     def parent_category(self) -> Optional[str]:
+        """Example GameInfo/CIV4EraInfos.xml the category is GameInfo."""
         parent = self.path.parent.name
         if self.path.parent.name == "XML":
             return None
@@ -66,11 +69,13 @@ class Civ4XmlFile:
 
     @property
     def root_key(self) -> str:
+        """Top level key."""
         if not self._parsed:
-            self.read()
+            self._read()
         return [key for key in self._parsed].pop()
 
     def types(self):
+        """These become the Enum's members."""
         root = self._parsed[self.root_key]
         key = list(root.keys())[-1]
         names = [(self.negative_one, -1)]
@@ -79,9 +84,10 @@ class Civ4XmlFile:
         return names
 
     def to_enum(self):
+        """Return and Enum derived from the XML file."""
         return Enum(self.enum_name, self.types())
 
-    def read(self) -> dict:
+    def _read(self) -> dict:
         if not self.path.exists():
             raise FileNotFoundError(f"{self.path} does not exist!")
         with open(self.path, "r") as xml_file:
@@ -90,14 +96,14 @@ class Civ4XmlFile:
 
 
 def xml_files_iter() -> Generator[Civ4XmlFile, None, None]:
-    """
-    Generator yielding every XML file that isn't a Schema or Text type.
-    BTS and Warlords files take precendence over vanilla.
+    """Generator yielding every XML file that isn't a Schema or Text type.
+
+    BTS takes precendence over Warlords and Warlords over vanilla.
+
     Example:
         if both <BTS path>/CIV4BuildingInfos.xml, <Vanilla path>/CIV4BuildingInfos.xml
             only yield the BTS one
     """
-
     # TODO replace the ugliness with a glob** of some kind
     game_dir = get_game_dir()
     vanilla_xml = game_dir / "Assets" / "XML"
@@ -128,8 +134,8 @@ def xml_files_iter() -> Generator[Civ4XmlFile, None, None]:
                     yield Civ4XmlFile(file_or_dir)
 
 
-def write_out_enum(e) -> None:
-    """Writes to stdout, use > to save to file"""
+def write_out_enum(e):
+    """Write Enum to stdout using a jinja template."""
     data = {
         "enum_name": e.__name__,
         "members": [{"name": m, "value": e[m].value} for m in e.__members__],
@@ -147,19 +153,16 @@ class {{ enum_name }}(Enum):
 
 
 def make_enums() -> None:
-    """Writes to stdout, use > to save to file"""
+    """Write all enums to stdout."""
     print("from enum import Enum")
     print()
     for xml_file in xml_files_iter():
         try:
-            xml_file.read()
+            xml_file._read()
         except UnicodeDecodeError:
+            # FIXME some files are not unicode encoded
             continue
         try:
             write_out_enum(xml_file.to_enum())
-        except:
+        except Exception:
             continue
-
-
-if __name__ == "__main__":
-    make_enums()
